.. liyi-cute documentation master file, created by
   sphinx-quickstart on Mon Jun  6 12:15:18 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to liyi-cute's documentation!
=====================================

NLP 文本处理辅助工具

.. toctree::
   :maxdepth: 1
   :caption: 目录:

   安装
   加载数据
   预处理
   统计
   可视化




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
